import re
from typing import List

NAUGHTY_SUBS: List[re.Pattern] = [
    re.compile(word, re.IGNORECASE)
    for word in [
        "shit",
        "fuck",
        "crap",
        "ass",
        "dick",
    ]
]

DEBUG_SUBS: List[str] = [
    "{} - any more detail for you, my LORD?",
    "Can I go home now? {}",
]

INFO_SUBS: List[str] = [
    "Ok, so I was told to tell you '{}' but whatever...",
    "You really went and did it, huh... {}",
    "I don't get paid enough for this. here: {}",
    "Ok, ok.. I get it you want some details, hold your horses... {}",
    "You have now been subscribed to Cat Facts Daily. Please text '{}' to 55055 to STOP.",
    "Whats that coming over the hill? Is it a monster? No, its your logging again ffs - {}",
    "Knock knock. Who's there? your stupid log event: {}",
    "{}. But what do you mean by that?",
    "\N{pile of poo}\N{pile of poo}\N{pile of poo} {}",  # todo: add full emojification
]

WARNING_SUBS: List[str] = [
    "{} - do something about it, asshole.",
    "Right, this right here? Its shit. Fix it: {}",
    "Did you do something stupid? Look: {}",
    "And one. And two. And.. wait that's not meant to happen... {}",
]

ERROR_PRE_LOGS: List[str] = [
    "SHIT! SHIT! SHIT!",
    "CRAP! CRAP! CRAP!",
    "FUCK! FUCK! FUCK!",
    "What the fuck just happened?!",
]

ERROR_SUBS: List[str] = [
    "Look at this shit! {}",
    "{}????? Are you FUCKING kidding me??",
    "You fucked it: {}",
    "God damn it! you dickhead! it happened: {}",
]



import logging as original_logging
import random
from typing import Any

from ._const import *

_config = {"potty_mouth": True}


class _AngryLogger(original_logging.Logger):
    @staticmethod
    def clean_up(message: str) -> str:
        if not _config["potty_mouth"]:
            for pattern in NAUGHTY_SUBS:
                message = pattern.sub("*****", message)
        return message

    def debug(self, msg: Any, *args: Any, **kwargs: Any) -> None:
        wrapper = random.choice(DEBUG_SUBS)
        wrapper = self.clean_up(wrapper)
        super().debug(wrapper.format(msg), *args, **kwargs)

    def info(self, msg: Any, *args: Any, **kwargs: Any) -> None:
        wrapper = random.choice(INFO_SUBS)
        wrapper = self.clean_up(wrapper)
        super().info(wrapper.format(msg), *args, **kwargs)

    def warning(self, msg: Any, *args: Any, **kwargs: Any) -> None:
        wrapper = random.choice(WARNING_SUBS)
        wrapper = self.clean_up(wrapper)
        super().warning(wrapper.format(msg), *args, **kwargs)

    def error(self, msg: Any, *args: Any, **kwargs: Any) -> None:
        if random.random() > 0.5:
            first_line = random.choice(ERROR_PRE_LOGS)
            first_line = self.clean_up(first_line)
            super().error(first_line)
        wrapper = random.choice(ERROR_SUBS)
        wrapper = self.clean_up(wrapper)
        super().error(wrapper.format(msg), *args, **kwargs)


def start(potty_mouth=True):
    _config["potty_mouth"] = potty_mouth
    my_regular_logger = original_logging.getLogger("regular_logger")
    my_regular_logger.info("Gosh this is going to be fun...")
    original_logging.setLoggerClass(_AngryLogger)
    my_angry_logger = original_logging.getLogger("angry_logger")
    my_angry_logger.info("You should be all set up now.")



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['angry_logger']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'angry-logger',
    'version': '1.0.1',
    'description': 'Make your logging more passive agressive. Or just agressive agressive.',
    'long_description': '\n[![version](https://img.shields.io/pypi/v/angry-logger)](https://pypi.org/project/angry-logger/)\n[![licence](https://img.shields.io/pypi/l/angry-logger)](https://github.com/GitToby/angry-logger)\n\n# Angry Logging Made Easy\n\nDo you want to show your logger to be more passive aggressive? maybe just actual aggressive? This is the library for\nyou.\n\n## Installation\nYou can install via pip!\n```shell\npip install angry-logger\n```\n\n## Usage\nWhen deciding your project needs more aggression, all you have to do is tell the Angry Logger to go to town. Like so.\n```python\nimport angry_logger\nangry_logger.start()\n```\nIf you\'re not a fan of naughty words, you can tell the angry logger to be less of a potty mouth.\n```python\nimport angry_logger\nangry_logger.start(potty_mouth=False)\n```\n\nFrom here, use your logging as you normally would.\n```python\nimport angry_logger\nimport logging\n\nangry_logger.start(potty_mouth=False)\nlogging.basicConfig(level=logging.DEBUG)\n\ntest_logger = logging.getLogger("test_logger")\n\ntest_logger.debug("this is a test debug message")\ntest_logger.info("this is a test info message")\ntest_logger.warning("this is a test warning message")\ntest_logger.error("this is a test error message")\n```\n\nThis will output your new normal, information hidden behind abuse.\n```\nDEBUG:test_logger:Can I go home now? this is a test debug message\nINFO:test_logger:this is a test info message. But what do you mean by that?\nWARNING:test_logger:Did you do something stupid? Look: this is a test warning message\nERROR:test_logger:this is a test error message????? Are you *****ING kidding me??\n```',
    'author': 'Toby Devlin',
    'author_email': 'toby@tobydevlin.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/GitToby/angry-logger',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
